# The admin in deliberately left blank.
#
# As the data stored in this app will primarily come from a PopIt API we don't
# want to let people edit it locally, usless they really know what they are
# doing.
#
# In time perhaps this admin will be smart enough that it can tell what data is
# from a live popit API instance, and what is locally created, and allow you to
# edit accordingly.
