// Same as default.js, but the name of the joe bloggs entry is changed.

exports.persons = {
  fredBloggs: {
    _id: "fred-bloggs",
    name: "Fred Bloggs",
  },
  joeBloggs: {
    _id: "joe-bloggs",
    name: "Josh Blaggs",
  },
};
