// See https://github.com/powmedia/pow-mongodb-fixtures for the format used in
// this file

exports.persons = {
  fredBloggs: {
    _id: "fred-bloggs",
    name: "Fred Bloggs",
  },
  joeBloggs: {
    _id: "joe-bloggs",
    name: "Joe Bloggs",
  },
};
